dbusutil

package
v1.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 21, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Overview

Package dbusutil provides shared D-Bus helpers for kcd plugins. It is the only internal package that imports godbus/dbus.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func PauseMPRIS

func PauseMPRIS(conn *dbus.Conn, logger *zap.Logger) []string

PauseMPRIS sends Pause to all active MPRIS media players. Returns the list of player bus names that were paused so Play can be sent later.

func PlayMPRIS

func PlayMPRIS(conn *dbus.Conn, players []string, logger *zap.Logger)

PlayMPRIS sends Play to the named MPRIS players.

Types

This section is empty.

Jump to