doctor

package
v1.13.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 27, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Overview

Package doctor performs runtime dependency and configuration checks.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Check

type Check struct {
	Name   string
	Detail string // shown on failure
	Pass   bool
}

Check is the result of a single diagnostic check.

func Run

func Run() []Check

Run performs all checks and returns their results in order.

Jump to