lockdevice

package
v1.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 21, 2026 License: MIT Imports: 9 Imported by: 0

Documentation

Overview

Package lockdevice implements the KDE Connect Lock Device plugin. It allows the phone to query and control the lock state of the Linux session.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type LockBody

type LockBody struct {
	RequestLocked bool `json:"requestLocked,omitempty"`
	SetLocked     bool `json:"setLocked,omitempty"`
	IsLocked      bool `json:"isLocked,omitempty"`
}

type LockDevicePlugin

type LockDevicePlugin struct {
	// contains filtered or unexported fields
}

LockDevicePlugin handles incoming lock/unlock requests from the phone.

func NewLockDevicePlugin

func NewLockDevicePlugin(logger *zap.Logger) *LockDevicePlugin

func (*LockDevicePlugin) Handle

func (p *LockDevicePlugin) Handle(ctx context.Context, dev device.Sender, pkt *protocol.Packet) error

func (*LockDevicePlugin) IncomingTypes

func (p *LockDevicePlugin) IncomingTypes() []string

func (*LockDevicePlugin) Lock

func (p *LockDevicePlugin) Lock(dev device.Sender) error

Lock triggers an immediate session lock from the daemon/IPC side.

func (*LockDevicePlugin) Name

func (p *LockDevicePlugin) Name() string

func (*LockDevicePlugin) OnConnect

func (p *LockDevicePlugin) OnConnect(dev device.Sender)

func (*LockDevicePlugin) OnDisconnect

func (p *LockDevicePlugin) OnDisconnect(dev device.Sender)

func (*LockDevicePlugin) OutgoingTypes

func (p *LockDevicePlugin) OutgoingTypes() []string

func (*LockDevicePlugin) Timeout

func (p *LockDevicePlugin) Timeout() time.Duration

func (*LockDevicePlugin) Unlock

func (p *LockDevicePlugin) Unlock(dev device.Sender) error

Unlock triggers an immediate session unlock from the daemon/IPC side.

Jump to