Documentation
¶
Overview ¶
Package dbusutil provides shared D-Bus helpers for kcd plugins. It is the only internal package that imports godbus/dbus.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func PauseMPRIS ¶
PauseMPRIS sends Pause to all active MPRIS media players. Returns the list of player bus names that were paused so Play can be sent later.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.