Documentation
¶
Overview ¶
Package lockdevice implements the KDE Connect Lock Device plugin. It allows the phone to query and control the lock state of the Linux session.
Index ¶
- type LockBody
- type LockDevicePlugin
- func (p *LockDevicePlugin) Handle(ctx context.Context, dev device.Sender, pkt *protocol.Packet) error
- func (p *LockDevicePlugin) IncomingTypes() []string
- func (p *LockDevicePlugin) Lock(dev device.Sender) error
- func (p *LockDevicePlugin) Name() string
- func (p *LockDevicePlugin) OnConnect(dev device.Sender)
- func (p *LockDevicePlugin) OnDisconnect(dev device.Sender)
- func (p *LockDevicePlugin) OutgoingTypes() []string
- func (p *LockDevicePlugin) Timeout() time.Duration
- func (p *LockDevicePlugin) Unlock(dev device.Sender) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type LockDevicePlugin ¶
type LockDevicePlugin struct {
// contains filtered or unexported fields
}
LockDevicePlugin handles incoming lock/unlock requests from the phone.
func NewLockDevicePlugin ¶
func NewLockDevicePlugin(logger *zap.Logger) *LockDevicePlugin
func (*LockDevicePlugin) IncomingTypes ¶
func (p *LockDevicePlugin) IncomingTypes() []string
func (*LockDevicePlugin) Lock ¶
func (p *LockDevicePlugin) Lock(dev device.Sender) error
Lock triggers an immediate session lock from the daemon/IPC side.
func (*LockDevicePlugin) Name ¶
func (p *LockDevicePlugin) Name() string
func (*LockDevicePlugin) OnConnect ¶
func (p *LockDevicePlugin) OnConnect(dev device.Sender)
func (*LockDevicePlugin) OnDisconnect ¶
func (p *LockDevicePlugin) OnDisconnect(dev device.Sender)
func (*LockDevicePlugin) OutgoingTypes ¶
func (p *LockDevicePlugin) OutgoingTypes() []string
func (*LockDevicePlugin) Timeout ¶
func (p *LockDevicePlugin) Timeout() time.Duration
Click to show internal directories.
Click to hide internal directories.