Documentation
¶
Index ¶
- type MousepadBody
- type MousepadPlugin
- func (p *MousepadPlugin) Handle(_ context.Context, _ device.Sender, pkt *protocol.Packet) error
- func (p *MousepadPlugin) IncomingTypes() []string
- func (p *MousepadPlugin) Name() string
- func (p *MousepadPlugin) OnConnect(dev device.Sender)
- func (p *MousepadPlugin) OnDisconnect(_ device.Sender)
- func (p *MousepadPlugin) OutgoingTypes() []string
- func (p *MousepadPlugin) Timeout() time.Duration
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MousepadBody ¶
type MousepadBody struct {
Dx float64 `json:"dx"`
Dy float64 `json:"dy"`
X float64 `json:"x"`
Y float64 `json:"y"`
SingleClick bool `json:"singleclick"`
DoubleClick bool `json:"doubleclick"`
MiddleClick bool `json:"middleclick"`
RightClick bool `json:"rightclick"`
SingleHold bool `json:"singlehold"`
SingleRel bool `json:"singlerelease"`
Scroll bool `json:"scroll"`
Key string `json:"key"`
SpecialKey int `json:"specialKey"`
Shift bool `json:"shift"`
Ctrl bool `json:"ctrl"`
Alt bool `json:"alt"`
Super bool `json:"super"`
}
MousepadBody represents the exact spec Android sends.
type MousepadPlugin ¶
type MousepadPlugin struct {
// contains filtered or unexported fields
}
func NewMousepadPlugin ¶
func NewMousepadPlugin(cfg config.MousepadConfig, logger *zap.Logger) *MousepadPlugin
func (*MousepadPlugin) IncomingTypes ¶
func (p *MousepadPlugin) IncomingTypes() []string
func (*MousepadPlugin) Name ¶
func (p *MousepadPlugin) Name() string
func (*MousepadPlugin) OnConnect ¶
func (p *MousepadPlugin) OnConnect(dev device.Sender)
OnConnect explicitly tells the Android app that this device supports Keyboard input. Without this, the Android app will not show the keyboard icon in the Remote Input UI.
func (*MousepadPlugin) OnDisconnect ¶
func (p *MousepadPlugin) OnDisconnect(_ device.Sender)
func (*MousepadPlugin) OutgoingTypes ¶
func (p *MousepadPlugin) OutgoingTypes() []string
func (*MousepadPlugin) Timeout ¶
func (p *MousepadPlugin) Timeout() time.Duration
Click to show internal directories.
Click to hide internal directories.