Documentation
¶
Overview ¶
Package client implements the local IPC client for kcdctl.
Index ¶
- type Client
- func (c *Client) Battery(deviceID string) (int, bool, error)
- func (c *Client) Call(cmd string, payload interface{}) (*ipc.Response, error)
- func (c *Client) CallMute(deviceID string) error
- func (c *Client) ClipboardPush(deviceID string) error
- func (c *Client) Connect(ip string) error
- func (c *Client) Devices() ([]device.DeviceInfo, error)
- func (c *Client) FindMyPhone(deviceID string) error
- func (c *Client) Lock(deviceID string) error
- func (c *Client) NotifyReply(deviceID, replyID, message string) error
- func (c *Client) Pair(deviceID string) error
- func (c *Client) Ping(deviceID string) error
- func (c *Client) RunExec(deviceID string, key string) error
- func (c *Client) RunList(deviceID string) error
- func (c *Client) SendSMS(deviceID, phoneNumber, message string) error
- func (c *Client) SftpMount(deviceID string) error
- func (c *Client) SftpMountLocal(deviceID string) error
- func (c *Client) ShareFile(deviceID string, filePath string) error
- func (c *Client) Unlock(deviceID string) error
- func (c *Client) Unpair(deviceID string) error
- func (c *Client) Watch(ctx context.Context, filter []string, ch chan<- events.Event) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
Client connects to the kcd daemon via Unix socket.
func (*Client) CallMute ¶
CallMute requests the daemon to mute an incoming call on the remote device.
func (*Client) ClipboardPush ¶
ClipboardPush triggers an outgoing clipboard sync from desktop to device.
func (*Client) Connect ¶ added in v1.0.1
Connect requests the daemon to manually connect to a device by IP.
func (*Client) Devices ¶
func (c *Client) Devices() ([]device.DeviceInfo, error)
Devices queries the daemon for all known devices.
func (*Client) FindMyPhone ¶
FindMyPhone requests the remote device to ring loudly.
func (*Client) NotifyReply ¶
NotifyReply requests the daemon to send a reply to an Android notification.
func (*Client) SftpMount ¶
SftpMount requests the daemon to initiate an SFTP connection to the remote device.
func (*Client) SftpMountLocal ¶
SftpMountLocal requests the daemon to physically mount the remote device via sshfs.